==> mongodb-6.0.25.gh.tar.gz: mongo-r6.0.25/src/mongo/scripting/mozjs/mongohelpers.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/scripting/mozjs/wraptype.h"

namespace mongo {
namespace mozjs {

/**
 * The "MongoHelpers" Javascript object.
 *
 * The MongoHelpers object is a special hidden object to attach internal-use
 * javascript code to the global object so that we can do things like access the
 * javascript parser through SpiderMonkey's reflection API, and parse function
 * bodies/expressions from the server code.
 */
struct MongoHelpersInfo : public BaseInfo {
    static void postInstall(JSContext* cx, JS::HandleObject global, JS::HandleObject proto);
    static const InstallType installType = InstallType::Private;
    static const char* const className;
};

std::string parseJSFunctionOrExpression(JSContext* cx, StringData input);

}  // namespace mozjs
}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/scripting/mozjs/mongohelpers.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <js/TypeDecls.h>
#include <string>

#include "mongo/base/string_data.h"
#include "mongo/scripting/mozjs/base.h"
#include "mongo/scripting/mozjs/wraptype.h"

namespace mongo {
namespace mozjs {

/**
 * The "MongoHelpers" Javascript object.
 *
 * The MongoHelpers object is a special hidden object to attach internal-use
 * javascript code to the global object so that we can do things like access the
 * javascript parser through SpiderMonkey's reflection API, and parse function
 * bodies/expressions from the server code.
 */
struct MongoHelpersInfo : public BaseInfo {
    static void postInstall(JSContext* cx, JS::HandleObject global, JS::HandleObject proto);
    static const InstallType installType = InstallType::Private;
    static const char* const className;
};

std::string parseJSFunctionOrExpression(JSContext* cx, StringData input);

}  // namespace mozjs
}  // namespace mongo
